import { SearchOptions } from './api/search';
import RateLimitError from './errors/RateLimitError';
import SongNotFoundError from './errors/SongNotFoundError';
import PlaylistNotFoundError from './errors/PlaylistNotFoundError';
interface BeatSaverAPIOptions {
    AppName: string;
    Version: string;
}
declare class BeatSaverAPI {
    private appName;
    private appVersion;
    private axiosInstance;
    constructor(options: BeatSaverAPIOptions);
    static get Errors(): {
        RateLimitError: typeof RateLimitError;
        SongNotFoundError: typeof SongNotFoundError;
        PlaylistNotFoundError: typeof PlaylistNotFoundError;
    };
    getMapByID(id: string): Promise<import("./models/MapDetail").MapDetail>;
    getMapByHash(hash: string): Promise<import("./models/MapDetail").MapDetail>;
    getMapsByUploader(userID: number, page?: number): Promise<import("./models/SearchResponse").SearchResponse>;
    getLatestMaps(automapper: boolean, before?: string): Promise<import("./models/SearchResponse").SearchResponse>;
    searchMaps(searchOptions: SearchOptions, page?: number): Promise<import("./models/SearchResponse").SearchResponse>;
    getLatestPlaylists(after: string, before: string, sort: 'UPDATED' | 'SONGS_UPDATED' | 'CREATED'): Promise<import("./models/PlaylistSearchResponse").PlaylistSearchResponse>;
    getPlaylistByID(id: number, page?: number): Promise<import("./models/PlaylistPage").PlaylistPage>;
    getPlaylistsByUser(userID: number, page?: number): Promise<import("./models/PlaylistSearchResponse").PlaylistSearchResponse>;
}
export = BeatSaverAPI;
